@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "basedevice.h"
+#include "parentdevice.h"
 #include "indidriver.h"
 #include "indilogger.h"
 
@@ -115,7 +115,7 @@ namespace INDI
 {
 
 class DefaultDevicePrivate;
-class DefaultDevice : public BaseDevice
+class DefaultDevice : public ParentDevice
 {
         DECLARE_PRIVATE(DefaultDevice)
 
@@ -149,7 +149,8 @@ class DefaultDevice : public BaseDevice
          * save configuration files.
          * \param nvp The number vector property to be defined
          */
-        void defineNumber(INumberVectorProperty *nvp) __attribute__((deprecated));
+        INDI_DEPRECATED("Use defineProperty(INDI::Property &).")
+        void defineNumber(INumberVectorProperty *nvp);
         void defineProperty(INumberVectorProperty *property);
 
         /**
@@ -158,7 +159,8 @@ class DefaultDevice : public BaseDevice
          * configuration files.
          * \param tvp The text vector property to be defined
          */
-        void defineText(ITextVectorProperty *tvp) __attribute__((deprecated));
+        INDI_DEPRECATED("Use defineProperty(INDI::Property &).")
+        void defineText(ITextVectorProperty *tvp);
         void defineProperty(ITextVectorProperty *property);
 
         /**
@@ -167,7 +169,8 @@ class DefaultDevice : public BaseDevice
          * configuration files.
          * \param svp The switch vector property to be defined
          */
-        void defineSwitch(ISwitchVectorProperty *svp) __attribute__((deprecated));
+        INDI_DEPRECATED("Use defineProperty(INDI::Property &).")
+        void defineSwitch(ISwitchVectorProperty *svp);
         void defineProperty(ISwitchVectorProperty *property);
 
         /**
@@ -176,7 +179,8 @@ class DefaultDevice : public BaseDevice
          * configuration files.
          * \param lvp The light vector property to be defined
          */
-        void defineLight(ILightVectorProperty *lvp) __attribute__((deprecated));
+        INDI_DEPRECATED("Use defineProperty(INDI::Property &).")
+        void defineLight(ILightVectorProperty *lvp);
         void defineProperty(ILightVectorProperty *property);
 
         /**
@@ -185,7 +189,8 @@ class DefaultDevice : public BaseDevice
          * save configuration files.
          * \param bvp The BLOB vector property to be defined
          */
-        void defineBLOB(IBLOBVectorProperty *bvp) __attribute__((deprecated));
+        INDI_DEPRECATED("Use defineProperty(INDI::Property &).")
+        void defineBLOB(IBLOBVectorProperty *bvp);
         void defineProperty(IBLOBVectorProperty *property);
 
         void defineProperty(INDI::Property &property);
@@ -199,7 +204,7 @@ class DefaultDevice : public BaseDevice
          * @brief deleteProperty Delete a property and unregister it. It will also be deleted from all clients.
          * @param property Property to be deleted.
          * @return True if successful, false otherwise.
-         * @note This is a convience function that internally calls deleteProperty with the property name.
+         * @note This is a convenience function that internally calls deleteProperty with the property name.
          */
         bool deleteProperty(INDI::Property &property);
 
@@ -304,20 +309,27 @@ class DefaultDevice : public BaseDevice
         /**
          * @return getInterface Return the interface declared by the driver.
          */
-        virtual uint16_t getDriverInterface() override;
+        uint32_t getDriverInterface() const;
 
         /**
          * @brief setInterface Set driver interface. By default the driver interface is set to GENERAL_DEVICE.
          * You may send an ORed list of DeviceInterface values.
          * @param value ORed list of DeviceInterface values.
          * @warning This only updates the internal driver interface property and does not send it to the
-         * client. To synchronize the client, use syncDriverInfo funciton.
+         * client. To synchronize the client, use syncDriverInfo function.
          */
-        void setDriverInterface(uint16_t value);
+        void setDriverInterface(uint32_t value);
+
+    public:
+        /** @brief Add a device to the watch list.
+         *
+         *  A driver may select to receive notifications of a specific other device.
+         */
+        void watchDevice(const char *deviceName, const std::function<void (INDI::BaseDevice)> &callback);
 
     protected:
         /**
-         * @brief setDynamicPropertiesBehavior controls handling of dynamic properties. Dyanmic properties
+         * @brief setDynamicPropertiesBehavior controls handling of dynamic properties. Dynamic properties
          * are those generated from an external skeleton XML file. By default all properties, including
          * dynamic properties, are defined to the client in ISGetProperties(). Furthermore, when
          * űdeleteProperty(properyName) is called, the dynamic property is deleted by default, and can only
@@ -439,8 +451,8 @@ class DefaultDevice : public BaseDevice
         bool isSimulation() const;
 
         /**
-         * \brief Initilize properties initial state and value. The child class must implement this function.
-         * \return True if initilization is successful, false otherwise.
+         * \brief Initialize properties initial state and value. The child class must implement this function.
+         * \return True if initialization is successful, false otherwise.
          */
         virtual bool initProperties();
 
@@ -557,9 +569,14 @@ class DefaultDevice : public BaseDevice
         friend class Connection::TCP;
         friend class FilterInterface;
         friend class FocuserInterface;
+        friend class WeatherInterface;
+        friend class LightBoxInterface;
+        friend class OutputInterface;
+        friend class InputInterface;
+        friend class PowerInterface;
 
     protected:
-        DefaultDevice(DefaultDevicePrivate &dd);
+        DefaultDevice(const std::shared_ptr<DefaultDevicePrivate> &dd);
 };
 
 }
